.. Ringo documentation master file, created by
   sphinx-quickstart on Mon Mar 18 17:46:35 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Ringo documentation
===================

.. toctree::
   :maxdepth: 2

   overview
   userguide/index
   architecture/index
   development/index
   administration/index


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
